pub async fn create_agent(config: AgentConfig) -> Result<Agent>Expand description
Validates capabilities, restores a checkpoint, and starts the agent loop.
Errors
Returns an error if validation or an operation required by this function fails.
pub async fn create_agent(config: AgentConfig) -> Result<Agent>Validates capabilities, restores a checkpoint, and starts the agent loop.
Returns an error if validation or an operation required by this function fails.