Kimi

Struct Kimi 

pub struct Kimi { /* private fields */ }
Kimi’s native Chat Completions provider.

Implementations

Source

impl Kimi

pub fn new( api_key: impl Into<String>, base_url: impl Into<String>, model: impl Into<String>, ) -> Result<Self>

Creates a provider for a Moonshot Kimi endpoint.

Errors

Returns an error if configuration is invalid or a required resource cannot be initialized.

pub fn with_reasoning_effort(self, effort: impl Into<String>) -> Result<Self>

Selects an effort advertised for this Kimi model.

Errors

Returns an error if validation or an operation required by this function fails.