pub struct ComputerControl { /* private fields */ }Expand description
Owns computer tools and observations; execution and approval remain in the sandbox.
Implementations
Sourceimpl ComputerControl
impl ComputerControl
Sourcepub fn new(
files: SessionFileStore,
worker: WorkerCommand,
documentation: PathBuf,
) -> Result<Self>
pub fn new( files: SessionFileStore, worker: WorkerCommand, documentation: PathBuf, ) -> Result<Self>
Configures a trusted installed runtime. It is started lazily by an authorized tool call.
Errors
Returns an error if configuration is invalid or a required resource cannot be initialized.