pub struct MessageQueue<'a> { /* private fields */ }Expand description
Mutable scoped view of messages retained until their delivery boundary.
Implementations
Sourceimpl<'a> MessageQueue<'a>
impl<'a> MessageQueue<'a>
Sourcepub fn latest(&self) -> Option<QueuedMessageView<'_>>
pub fn latest(&self) -> Option<QueuedMessageView<'_>>
Returns the newest message available to this context.
Sourcepub fn find(&self, id: &str) -> Option<QueuedMessageView<'_>>
pub fn find(&self, id: &str) -> Option<QueuedMessageView<'_>>
Returns one owned item by its revision identity.
Sourcepub fn enqueue(
&mut self,
id: &str,
boundary: QueuedMessageBoundary,
event: MessageEvent,
) -> Result<bool>
pub fn enqueue( &mut self, id: &str, boundary: QueuedMessageBoundary, event: MessageEvent, ) -> Result<bool>
Appends one prepared message, or returns false when it is full or duplicated.