pub struct TurnEndContext<'a> {
pub session_id: &'a str,
pub turn_id: &'a str,
pub events: &'a mut Vec<EventMsg>,
/* private fields */
}Expand description
State exposed when the loop finishes or aborts a turn.
Fields
session_id: &'a strturn_id: &'a strevents: &'a mut Vec<EventMsg>Implementations
Sourceimpl TurnEndContext<'_>
impl TurnEndContext<'_>
pub fn outcome(&self) -> ExecutionOutcome
Sourcepub fn queued_messages(&self) -> impl Iterator<Item = QueuedMessageView<'_>>
pub fn queued_messages(&self) -> impl Iterator<Item = QueuedMessageView<'_>>
Returns queued messages still pending for this middleware, oldest first.