pub async fn create_agent(config: AgentConfig) -> Result<Agent>Expand description
Validates capabilities, restores a checkpoint, and starts the agent loop.
pub async fn create_agent(config: AgentConfig) -> Result<Agent>Validates capabilities, restores a checkpoint, and starts the agent loop.