pub struct Sandbox { /* private fields */ }Expand description
Approval-owning boundary around one execution backend.
Implementations
Sourceimpl Sandbox
impl Sandbox
Sourcepub fn new(backend: Arc<dyn SandboxBackend>, policy: ApprovalPolicy) -> Self
pub fn new(backend: Arc<dyn SandboxBackend>, policy: ApprovalPolicy) -> Self
Creates a sandbox with its initial approval policy.
Sourcepub fn approval_reviewer(self, reviewer: ApprovalReviewerConfig) -> Self
pub fn approval_reviewer(self, reviewer: ApprovalReviewerConfig) -> Self
Configures the isolated model reviewer used by automatic approval.
Sourcepub fn read_bytes<'a>(
&'a self,
path: &'a str,
max_bytes: usize,
) -> BoxFuture<'a, Result<Vec<u8>>>
pub fn read_bytes<'a>( &'a self, path: &'a str, max_bytes: usize, ) -> BoxFuture<'a, Result<Vec<u8>>>
Reads one bounded binary file.
Sourcepub fn write<'a>(
&'a self,
path: &'a str,
content: &'a str,
permissions: &'a ToolPermissions,
) -> BoxFuture<'a, Result<()>>
pub fn write<'a>( &'a self, path: &'a str, content: &'a str, permissions: &'a ToolPermissions, ) -> BoxFuture<'a, Result<()>>
Writes a UTF-8 file when this call has mutation authority.
Sourcepub fn execute<'a>(
&'a self,
command: &'a str,
permissions: &'a ToolPermissions,
) -> BoxFuture<'a, Result<CommandOutput>>
pub fn execute<'a>( &'a self, command: &'a str, permissions: &'a ToolPermissions, ) -> BoxFuture<'a, Result<CommandOutput>>
Runs a command when this call has mutation authority.