Context compaction policy and provider routing.
Structs
- Compaction
- Compacts visible context after a configurable token threshold.
Enums
- Compaction
Mode - Policy used when a conversation reaches its context threshold.
Constants
- DEFAULT_
COMPACTION_ TOKENS - Default compaction trigger for middleware instances without an override.
- MANIFEST
- Configuration and presentation metadata for compaction.